summaryrefslogtreecommitdiff
path: root/storage
diff options
context:
space:
mode:
authorOtto Kekäläinen <otto@seravo.fi>2016-03-04 02:09:37 +0200
committerOtto Kekäläinen <otto@seravo.fi>2016-03-04 02:09:37 +0200
commit1777fd5f556a9c68cae01ad2aadaf4865984e649 (patch)
tree931f4a045467951a6ef8833631d6f0aeb04b53c3 /storage
parentf8251911a44f6b65c2377e9945e208e240dfec33 (diff)
downloadmariadb-git-1777fd5f556a9c68cae01ad2aadaf4865984e649.tar.gz
Fix spelling: occurred, execute, which etc
Diffstat (limited to 'storage')
-rw-r--r--storage/archive/ha_archive.cc2
-rw-r--r--storage/connect/plgcnx.h2
-rw-r--r--storage/connect/tabdos.cpp2
-rw-r--r--storage/connect/tabmysql.cpp2
-rw-r--r--storage/connect/tabodbc.cpp2
-rw-r--r--storage/connect/value.cpp4
-rw-r--r--storage/csv/ha_tina.h2
-rw-r--r--storage/federated/ha_federated.cc2
-rw-r--r--storage/federatedx/ha_federatedx.cc2
-rw-r--r--storage/innobase/fts/fts0opt.cc2
-rw-r--r--storage/innobase/os/os0file.cc4
-rw-r--r--storage/maria/ma_packrec.c2
-rw-r--r--storage/myisam/ha_myisam.cc2
-rw-r--r--storage/myisam/mi_packrec.c2
-rw-r--r--storage/myisam/myisamlog.c2
-rw-r--r--storage/ndb/include/ndbapi/NdbEventOperation.hpp6
-rw-r--r--storage/ndb/include/ndbapi/NdbOperation.hpp4
-rw-r--r--storage/ndb/include/ndbapi/NdbTransaction.hpp4
-rw-r--r--storage/ndb/include/newtonapi/dba.h2
-rw-r--r--storage/ndb/src/cw/cpcd/CPCD.hpp10
-rw-r--r--storage/ndb/src/kernel/blocks/dbacc/DbaccMain.cpp2
-rw-r--r--storage/ndb/src/kernel/blocks/dbdict/Dbdict.cpp2
-rw-r--r--storage/ndb/src/kernel/blocks/dbtc/DbtcMain.cpp2
-rw-r--r--storage/ndb/src/kernel/blocks/qmgr/QmgrMain.cpp2
-rw-r--r--storage/ndb/src/kernel/vm/Emulator.cpp2
-rw-r--r--storage/ndb/src/mgmsrv/MgmtSrvr.hpp2
-rw-r--r--storage/ndb/src/ndbapi/NdbDictionaryImpl.hpp2
-rw-r--r--storage/ndb/src/ndbapi/NdbTransaction.cpp4
-rw-r--r--storage/ndb/src/ndbapi/Ndbif.cpp4
-rw-r--r--storage/ndb/test/include/NDBT_Error.hpp2
-rw-r--r--storage/ndb/test/ndbapi/flexAsynch.cpp2
-rw-r--r--storage/ndb/test/ndbapi/flexTimedAsynch.cpp2
-rw-r--r--storage/ndb/test/ndbapi/initronja.cpp8
-rw-r--r--storage/ndb/test/ndbapi/testNdbApi.cpp2
-rw-r--r--storage/ndb/test/ndbapi/testTimeout.cpp4
-rw-r--r--storage/ndb/test/ndbapi/test_event.cpp4
-rw-r--r--storage/ndb/test/ndbapi/test_event_multi_table.cpp2
-rw-r--r--storage/ndb/tools/restore/restore_main.cpp4
-rw-r--r--storage/xtradb/fts/fts0opt.cc2
-rw-r--r--storage/xtradb/os/os0file.cc4
40 files changed, 59 insertions, 59 deletions
diff --git a/storage/archive/ha_archive.cc b/storage/archive/ha_archive.cc
index c1acef4596f..00f3adb07ee 100644
--- a/storage/archive/ha_archive.cc
+++ b/storage/archive/ha_archive.cc
@@ -56,7 +56,7 @@
meta file is first opened it is marked as dirty. It is opened when the table
itself is opened for writing. When the table is closed the new count for rows
is written to the meta file and the file is marked as clean. If the meta file
- is opened and it is marked as dirty, it is assumed that a crash occured. At
+ is opened and it is marked as dirty, it is assumed that a crash occurred. At
this point an error occurs and the user is told to rebuild the file.
A rebuild scans the rows and rewrites the meta file. If corruption is found
in the data file then the meta file is not repaired.
diff --git a/storage/connect/plgcnx.h b/storage/connect/plgcnx.h
index a1208f9b885..1b341bc5275 100644
--- a/storage/connect/plgcnx.h
+++ b/storage/connect/plgcnx.h
@@ -25,7 +25,7 @@ enum FNRC {RC_LICENSE = 7, /* PLGConnect prompt for license key */
RC_SUCCESS = 0, /* Successful function (must be 0) */
RC_MEMORY = -1, /* Storage allocation error */
RC_TRUNCATED = -2, /* Result has been truncated */
- RC_TIMEOUT = -3, /* Connection timeout occured */
+ RC_TIMEOUT = -3, /* Connection timeout occurred */
RC_TOOBIG = -4, /* Data is too big for connection */
RC_KEY = -5, /* Null ptr to key in Connect */
/* or bad key in other functions */
diff --git a/storage/connect/tabdos.cpp b/storage/connect/tabdos.cpp
index 7906f6c9219..98633f49d23 100644
--- a/storage/connect/tabdos.cpp
+++ b/storage/connect/tabdos.cpp
@@ -184,7 +184,7 @@ bool DOSDEF::GetOptFileName(PGLOBAL g, char *filename)
} // end of GetOptFileName
/***********************************************************************/
-/* After an optimize error occured, remove all set optimize values. */
+/* After an optimize error occurred, remove all set optimize values. */
/***********************************************************************/
void DOSDEF::RemoveOptValues(PGLOBAL g)
{
diff --git a/storage/connect/tabmysql.cpp b/storage/connect/tabmysql.cpp
index 5a8bb17bd50..98887269c2e 100644
--- a/storage/connect/tabmysql.cpp
+++ b/storage/connect/tabmysql.cpp
@@ -806,7 +806,7 @@ int TDBMYSQL::GetMaxSize(PGLOBAL g)
else if (!Cardinality(NULL))
MaxSize = 10; // To make MySQL happy
else if ((MaxSize = Cardinality(g)) < 0)
- MaxSize = 12; // So we can see an error occured
+ MaxSize = 12; // So we can see an error occurred
} // endif MaxSize
diff --git a/storage/connect/tabodbc.cpp b/storage/connect/tabodbc.cpp
index fd9a049a05a..2c039c97a30 100644
--- a/storage/connect/tabodbc.cpp
+++ b/storage/connect/tabodbc.cpp
@@ -818,7 +818,7 @@ int TDBODBC::GetMaxSize(PGLOBAL g)
else if (!Cardinality(NULL))
MaxSize = 10; // To make MySQL happy
else if ((MaxSize = Cardinality(g)) < 0)
- MaxSize = 12; // So we can see an error occured
+ MaxSize = 12; // So we can see an error occurred
} // endif MaxSize
diff --git a/storage/connect/value.cpp b/storage/connect/value.cpp
index f9597cb842b..80a694bfc26 100644
--- a/storage/connect/value.cpp
+++ b/storage/connect/value.cpp
@@ -989,7 +989,7 @@ uchar TYPVAL<uchar>::MinMaxVal(bool b)
{return (b) ? UINT_MAX8 : 0;}
/***********************************************************************/
-/* SafeAdd: adds a value and test whether overflow/underflow occured. */
+/* SafeAdd: adds a value and test whether overflow/underflow occurred. */
/***********************************************************************/
template <class TYPE>
TYPE TYPVAL<TYPE>::SafeAdd(TYPE n1, TYPE n2)
@@ -1017,7 +1017,7 @@ inline double TYPVAL<double>::SafeAdd(double n1, double n2)
} // end of SafeAdd
/***********************************************************************/
-/* SafeMult: multiply values and test whether overflow occured. */
+/* SafeMult: multiply values and test whether overflow occurred. */
/***********************************************************************/
template <class TYPE>
TYPE TYPVAL<TYPE>::SafeMult(TYPE n1, TYPE n2)
diff --git a/storage/csv/ha_tina.h b/storage/csv/ha_tina.h
index 000b46b2bb2..127c6053a53 100644
--- a/storage/csv/ha_tina.h
+++ b/storage/csv/ha_tina.h
@@ -71,7 +71,7 @@ class ha_tina: public handler
File update_temp_file;
String buffer;
/*
- The chain contains "holes" in the file, occured because of
+ The chain contains "holes" in the file, occurred because of
deletes/updates. It is used in rnd_end() to get rid of them
in the end of the query.
*/
diff --git a/storage/federated/ha_federated.cc b/storage/federated/ha_federated.cc
index 4ea91dd9e68..97baa27aba6 100644
--- a/storage/federated/ha_federated.cc
+++ b/storage/federated/ha_federated.cc
@@ -2016,7 +2016,7 @@ void ha_federated::start_bulk_insert(ha_rows rows, uint flags)
@return Operation status
@retval 0 No error
- @retval != 0 Error occured at remote server. Also sets my_errno.
+ @retval != 0 Error occurred at remote server. Also sets my_errno.
*/
int ha_federated::end_bulk_insert()
diff --git a/storage/federatedx/ha_federatedx.cc b/storage/federatedx/ha_federatedx.cc
index 132cccc9c0f..9ee9a8d030f 100644
--- a/storage/federatedx/ha_federatedx.cc
+++ b/storage/federatedx/ha_federatedx.cc
@@ -2157,7 +2157,7 @@ void ha_federatedx::start_bulk_insert(ha_rows rows, uint flags)
@return Operation status
@retval 0 No error
- @retval != 0 Error occured at remote server. Also sets my_errno.
+ @retval != 0 Error occurred at remote server. Also sets my_errno.
*/
int ha_federatedx::end_bulk_insert()
diff --git a/storage/innobase/fts/fts0opt.cc b/storage/innobase/fts/fts0opt.cc
index 2a0aa4daf12..00b3b4682c3 100644
--- a/storage/innobase/fts/fts0opt.cc
+++ b/storage/innobase/fts/fts0opt.cc
@@ -598,7 +598,7 @@ fts_zip_read_word(
/* Finished decompressing block. */
if (zip->zp->avail_in == 0) {
- /* Free the block thats been decompressed. */
+ /* Free the block that's been decompressed. */
if (zip->pos > 0) {
ulint prev = zip->pos - 1;
diff --git a/storage/innobase/os/os0file.cc b/storage/innobase/os/os0file.cc
index c5ba4280c17..1c8861154ad 100644
--- a/storage/innobase/os/os0file.cc
+++ b/storage/innobase/os/os0file.cc
@@ -2677,7 +2677,7 @@ try_again:
"Error in system call pread(). The operating"
" system error number is %lu.",(ulint) errno);
} else {
- /* Partial read occured */
+ /* Partial read occurred */
ib_logf(IB_LOG_LEVEL_ERROR,
"Tried to read " ULINTPF " bytes at offset "
UINT64PF ". Was only able to read %ld.",
@@ -2808,7 +2808,7 @@ try_again:
"Error in system call pread(). The operating"
" system error number is %lu.",(ulint) errno);
} else {
- /* Partial read occured */
+ /* Partial read occurred */
ib_logf(IB_LOG_LEVEL_ERROR,
"Tried to read " ULINTPF " bytes at offset "
UINT64PF ". Was only able to read %ld.",
diff --git a/storage/maria/ma_packrec.c b/storage/maria/ma_packrec.c
index a541a657ed2..6a4e7ea99cf 100644
--- a/storage/maria/ma_packrec.c
+++ b/storage/maria/ma_packrec.c
@@ -1204,7 +1204,7 @@ static void decode_bytes(MARIA_COLUMNDEF *rec,MARIA_BIT_BUFF *bit_buff,
/* This means that the Huffman code must be longer than table_bits. */
pos=decode_tree->table+low_byte;
bits-=table_bits;
- /* NOTE: decode_bytes_test_bit() is a macro wich contains a break !!! */
+ /* NOTE: decode_bytes_test_bit() is a macro which contains a break !!! */
for (;;)
{
low_byte=(uint) (bit_buff->current_byte >> (bits-8));
diff --git a/storage/myisam/ha_myisam.cc b/storage/myisam/ha_myisam.cc
index 2fe519da794..d97aa503d42 100644
--- a/storage/myisam/ha_myisam.cc
+++ b/storage/myisam/ha_myisam.cc
@@ -2405,7 +2405,7 @@ maria_declare_plugin_end;
@return The error code. The engine_data and engine_callback will be set to 0.
@retval TRUE Success
- @retval FALSE An error occured
+ @retval FALSE An error occurred
*/
my_bool ha_myisam::register_query_cache_table(THD *thd, char *table_name,
diff --git a/storage/myisam/mi_packrec.c b/storage/myisam/mi_packrec.c
index d1ad911d334..eeadb70ae81 100644
--- a/storage/myisam/mi_packrec.c
+++ b/storage/myisam/mi_packrec.c
@@ -1158,7 +1158,7 @@ static void decode_bytes(MI_COLUMNDEF *rec,MI_BIT_BUFF *bit_buff,uchar *to,
/* This means that the Huffman code must be longer than table_bits. */
pos=decode_tree->table+low_byte;
bits-=table_bits;
- /* NOTE: decode_bytes_test_bit() is a macro wich contains a break !!! */
+ /* NOTE: decode_bytes_test_bit() is a macro which contains a break !!! */
for (;;)
{
low_byte=(uint) (bit_buff->current_byte >> (bits-8));
diff --git a/storage/myisam/myisamlog.c b/storage/myisam/myisamlog.c
index d549dd76037..7ce03ca9485 100644
--- a/storage/myisam/myisamlog.c
+++ b/storage/myisam/myisamlog.c
@@ -266,7 +266,7 @@ static void get_options(register int *argc, register char ***argv)
puts(" -u \"update\" -v \"verbose\" -w \"write file\"");
puts(" -D \"myisam compiled with DBUG\" -P \"processes\"");
puts("\nOne can give a second and a third '-v' for more verbose.");
- puts("Normaly one does a update (-u).");
+ puts("Normally one does a update (-u).");
puts("If a recover is done all writes and all possibly updates and deletes is done\nand errors are only counted.");
puts("If one gives table names as arguments only these tables will be updated\n");
help=1;
diff --git a/storage/ndb/include/ndbapi/NdbEventOperation.hpp b/storage/ndb/include/ndbapi/NdbEventOperation.hpp
index 5f41f30a38b..62a85bb3149 100644
--- a/storage/ndb/include/ndbapi/NdbEventOperation.hpp
+++ b/storage/ndb/include/ndbapi/NdbEventOperation.hpp
@@ -34,7 +34,7 @@ class NdbEventOperationImpl;
* Ndb::createEventOperation()
* - execute() starts the event flow. Use Ndb::pollEvents() to wait
* for an event to occur. Use Ndb::nextEvent() to iterate
- * through the events that have occured.
+ * through the events that have occurred.
* - The instance is removed by Ndb::dropEventOperation()
*
* For more info see:
@@ -63,7 +63,7 @@ class NdbEventOperationImpl;
* - Event code does not check table schema version. Make sure to drop events
* after table is dropped. Will be fixed in later
* versions.
- * - If a node failure has occured not all events will be recieved
+ * - If a node failure has occurred not all events will be recieved
* anymore. Drop NdbEventOperation and Create again after nodes are up
* again. Will be fixed in later versions.
*
@@ -167,7 +167,7 @@ public:
bool isConsistent() const;
/**
- * Query for occured event type.
+ * Query for occurred event type.
*
* @note Only valid after Ndb::nextEvent() has been called and
* returned a not NULL value
diff --git a/storage/ndb/include/ndbapi/NdbOperation.hpp b/storage/ndb/include/ndbapi/NdbOperation.hpp
index 9049c8cdd22..9b2b2f92818 100644
--- a/storage/ndb/include/ndbapi/NdbOperation.hpp
+++ b/storage/ndb/include/ndbapi/NdbOperation.hpp
@@ -761,9 +761,9 @@ public:
const NdbError & getNdbError() const;
/**
- * Get the method number where the error occured.
+ * Get the method number where the error occurred.
*
- * @return method number where the error occured.
+ * @return method number where the error occurred.
*/
int getNdbErrorLine();
diff --git a/storage/ndb/include/ndbapi/NdbTransaction.hpp b/storage/ndb/include/ndbapi/NdbTransaction.hpp
index f3eea49d19d..b11ce87e680 100644
--- a/storage/ndb/include/ndbapi/NdbTransaction.hpp
+++ b/storage/ndb/include/ndbapi/NdbTransaction.hpp
@@ -521,9 +521,9 @@ public:
NdbOperation* getNdbErrorOperation();
/**
- * Get the method number where the latest error occured.
+ * Get the method number where the latest error occurred.
*
- * @return Line number where latest error occured.
+ * @return Line number where latest error occurred.
*/
int getNdbErrorLine();
diff --git a/storage/ndb/include/newtonapi/dba.h b/storage/ndb/include/newtonapi/dba.h
index b02a7abb8af..c38545c9ec8 100644
--- a/storage/ndb/include/newtonapi/dba.h
+++ b/storage/ndb/include/newtonapi/dba.h
@@ -124,7 +124,7 @@ typedef enum {
DBA_SCHEMA_ERROR = 4, /**< Table already exists */
DBA_INSUFFICIENT_SPACE = 5, /**< The DB is full */
- DBA_TEMPORARY_ERROR = 6, /**< Some temporary problem occured */
+ DBA_TEMPORARY_ERROR = 6, /**< Some temporary problem occurred */
DBA_TIMEOUT = 7, /**< The request timed out, probably due to
dead-lock */
DBA_OVERLOAD = 8, /**< The DB is overloaded */
diff --git a/storage/ndb/src/cw/cpcd/CPCD.hpp b/storage/ndb/src/cw/cpcd/CPCD.hpp
index 3c2934c0f49..38c498f3b67 100644
--- a/storage/ndb/src/cw/cpcd/CPCD.hpp
+++ b/storage/ndb/src/cw/cpcd/CPCD.hpp
@@ -148,7 +148,7 @@ public:
*
* @return
* - 0 if successful
- - -1 and sets errno if an error occured
+ - -1 and sets errno if an error occurred
*/
int writePid(int pid);
@@ -308,7 +308,7 @@ public:
* - true if the addition was successful,
* - false if not
* - RequestStatus will be filled in with a suitable error
- * if an error occured.
+ * if an error occurred.
*/
bool defineProcess(RequestStatus *rs, Process * arg);
@@ -320,7 +320,7 @@ public:
* - true if the removal was successful,
* - false if not
* - The RequestStatus will be filled in with a suitable error
- * if an error occured.
+ * if an error occurred.
*/
bool undefineProcess(RequestStatus *rs, int id);
@@ -334,7 +334,7 @@ public:
* - true if the marking was successful
* - false if not
* - RequestStatus will be filled in with a suitable error
- * if an error occured.
+ * if an error occurred.
*/
bool startProcess(RequestStatus *rs, int id);
@@ -344,7 +344,7 @@ public:
* - true if the marking was successful
* - false if not
* - The RequestStatus will be filled in with a suitable error
- * if an error occured.
+ * if an error occurred.
*/
bool stopProcess(RequestStatus *rs, int id);
diff --git a/storage/ndb/src/kernel/blocks/dbacc/DbaccMain.cpp b/storage/ndb/src/kernel/blocks/dbacc/DbaccMain.cpp
index da614b0276c..e63d7e523b9 100644
--- a/storage/ndb/src/kernel/blocks/dbacc/DbaccMain.cpp
+++ b/storage/ndb/src/kernel/blocks/dbacc/DbaccMain.cpp
@@ -8107,7 +8107,7 @@ void Dbacc::seizeOverRec(Signal* signal) {
/**
- * A ZPAGESIZE_ERROR has occured, out of index pages
+ * A ZPAGESIZE_ERROR has occurred, out of index pages
* Print some debug info if debug compiled
*/
void Dbacc::zpagesize_error(const char* where){
diff --git a/storage/ndb/src/kernel/blocks/dbdict/Dbdict.cpp b/storage/ndb/src/kernel/blocks/dbdict/Dbdict.cpp
index e0e0a496e0a..c80e1455b31 100644
--- a/storage/ndb/src/kernel/blocks/dbdict/Dbdict.cpp
+++ b/storage/ndb/src/kernel/blocks/dbdict/Dbdict.cpp
@@ -10860,7 +10860,7 @@ Dbdict::execSUB_REMOVE_REF(Signal* signal)
OpSubEventPtr subbPtr;
c_opSubEvent.getPtr(subbPtr, ref->senderData);
if (err == 1407) {
- // conf this since this may occur if a nodefailure has occured
+ // conf this since this may occur if a nodefailure has occurred
// earlier so that the systable was not cleared
SubRemoveConf* conf = (SubRemoveConf*) signal->getDataPtrSend();
conf->senderRef = reference();
diff --git a/storage/ndb/src/kernel/blocks/dbtc/DbtcMain.cpp b/storage/ndb/src/kernel/blocks/dbtc/DbtcMain.cpp
index f4b0e07854c..419725b3487 100644
--- a/storage/ndb/src/kernel/blocks/dbtc/DbtcMain.cpp
+++ b/storage/ndb/src/kernel/blocks/dbtc/DbtcMain.cpp
@@ -6941,7 +6941,7 @@ void Dbtc::execSCAN_HBREP(Signal* signal)
}//execSCAN_HBREP()
/*--------------------------------------------------------------------------*/
-/* Timeout has occured on a fragment which means a scan has timed out. */
+/* Timeout has occurred on a fragment which means a scan has timed out. */
/* If this is true we have an error in LQH/ACC. */
/*--------------------------------------------------------------------------*/
void Dbtc::timeOutFoundFragLab(Signal* signal, UintR TscanConPtr)
diff --git a/storage/ndb/src/kernel/blocks/qmgr/QmgrMain.cpp b/storage/ndb/src/kernel/blocks/qmgr/QmgrMain.cpp
index 1a309e34c2d..a6b05283521 100644
--- a/storage/ndb/src/kernel/blocks/qmgr/QmgrMain.cpp
+++ b/storage/ndb/src/kernel/blocks/qmgr/QmgrMain.cpp
@@ -3817,7 +3817,7 @@ void Qmgr::systemErrorLab(Signal* signal, Uint32 line, const char * message)
// Broadcast that this node is failing to other nodes
failReport(signal, getOwnNodeId(), (UintR)ZTRUE, FailRep::ZOWN_FAILURE);
- // If it's known why shutdown occured
+ // If it's known why shutdown occurred
// an error message has been passed to this function
progError(line, NDBD_EXIT_NDBREQUIRE, message);
diff --git a/storage/ndb/src/kernel/vm/Emulator.cpp b/storage/ndb/src/kernel/vm/Emulator.cpp
index 6610d88fba0..ca278ccbc3c 100644
--- a/storage/ndb/src/kernel/vm/Emulator.cpp
+++ b/storage/ndb/src/kernel/vm/Emulator.cpp
@@ -246,7 +246,7 @@ NdbShutdown(NdbShutdownType type,
}
if(type != NST_Normal && type != NST_Restart){
- // Signal parent that error occured during startup
+ // Signal parent that error occurred during startup
if (type == NST_ErrorHandlerStartup)
kill(getppid(), SIGUSR1);
g_eventLogger.info("Error handler shutdown completed - %s", exitAbort);
diff --git a/storage/ndb/src/mgmsrv/MgmtSrvr.hpp b/storage/ndb/src/mgmsrv/MgmtSrvr.hpp
index 255a3e962ea..49533667b39 100644
--- a/storage/ndb/src/mgmsrv/MgmtSrvr.hpp
+++ b/storage/ndb/src/mgmsrv/MgmtSrvr.hpp
@@ -627,7 +627,7 @@ private:
NodeId m_master_node;
/**
- * Handles the thread wich upon a 'Node is started' event will
+ * Handles the thread which upon a 'Node is started' event will
* set the node's previous loglevel settings.
*/
struct NdbThread* _logLevelThread;
diff --git a/storage/ndb/src/ndbapi/NdbDictionaryImpl.hpp b/storage/ndb/src/ndbapi/NdbDictionaryImpl.hpp
index e3cf3488ce7..a647d387142 100644
--- a/storage/ndb/src/ndbapi/NdbDictionaryImpl.hpp
+++ b/storage/ndb/src/ndbapi/NdbDictionaryImpl.hpp
@@ -437,7 +437,7 @@ public:
bool setTransporter(class Ndb * ndb, class TransporterFacade * tf);
bool setTransporter(class TransporterFacade * tf);
- // To abstract the stuff thats made in all create/drop/lists below
+ // To abstract the stuff that's made in all create/drop/lists below
int dictSignal(NdbApiSignal* signal, LinearSectionPtr ptr[3], int secs,
int nodeId, // -1 any, 0 = master, >1 = specified
WaitSignalType wst,
diff --git a/storage/ndb/src/ndbapi/Ndbif.cpp b/storage/ndb/src/ndbapi/Ndbif.cpp
index ba3aebc5800..3608ec962f9 100644
--- a/storage/ndb/src/ndbapi/Ndbif.cpp
+++ b/storage/ndb/src/ndbapi/Ndbif.cpp
@@ -1315,7 +1315,7 @@ int sendPollNdb(int aMillisecondNumber, int minNoOfEventsToWakeup = 1, int force
Remark: First send all prepared operations and then check if there are any
transactions already completed. Wait for not completed
transactions until the specified number have completed or until the
- timeout has occured. Timeout zero means no waiting time.
+ timeout has occurred. Timeout zero means no waiting time.
******************************************************************************/
int
Ndb::sendPollNdb(int aMillisecondNumber, int minNoOfEventsToWakeup, int forceSend)
@@ -1359,7 +1359,7 @@ int pollNdb(int aMillisecondNumber, int minNoOfEventsToWakeup);
Remark: Check if there are any transactions already completed. Wait for not
completed transactions until the specified number have completed or
- until the timeout has occured. Timeout zero means no waiting time.
+ until the timeout has occurred. Timeout zero means no waiting time.
******************************************************************************/
int
Ndb::pollNdb(int aMillisecondNumber, int minNoOfEventsToWakeup)
diff --git a/storage/ndb/test/include/NDBT_Error.hpp b/storage/ndb/test/include/NDBT_Error.hpp
index 1d057d6b90f..9b04b76cf0e 100644
--- a/storage/ndb/test/include/NDBT_Error.hpp
+++ b/storage/ndb/test/include/NDBT_Error.hpp
@@ -79,7 +79,7 @@ private:
//
// ERR prints an NdbError object together with a description of where the
-// error occured
+// error occurred
//
#define ERR_OUT(where, error) \
{ where << "ERROR: " << error.code << " " \
diff --git a/storage/ndb/test/ndbapi/flexAsynch.cpp b/storage/ndb/test/ndbapi/flexAsynch.cpp
index d24965a9134..182baec2b91 100644
--- a/storage/ndb/test/ndbapi/flexAsynch.cpp
+++ b/storage/ndb/test/ndbapi/flexAsynch.cpp
@@ -618,7 +618,7 @@ executeCallback(int result, NdbConnection* NdbObject, void* aObject)
ndbout_c("execute: %s", NdbObject->getNdbError().message);
}//if(retCode == 3)
- // ndbout << "Error occured in poll:" << endl;
+ // ndbout << "Error occurred in poll:" << endl;
// ndbout << NdbObject->getNdbError() << endl;
failed++ ;
return;
diff --git a/storage/ndb/test/ndbapi/flexTimedAsynch.cpp b/storage/ndb/test/ndbapi/flexTimedAsynch.cpp
index 2a846008c56..c3b176fbaa8 100644
--- a/storage/ndb/test/ndbapi/flexTimedAsynch.cpp
+++ b/storage/ndb/test/ndbapi/flexTimedAsynch.cpp
@@ -512,7 +512,7 @@ executeCallback(int result, NdbConnection* NdbObject, void* aObject)
ndbout_c("execute: %s", NdbObject->getNdbError().message);
}//if(retCode == 3)
- // ndbout << "Error occured in poll:" << NdbObject->getNdbError() <<
+ // ndbout << "Error occurred in poll:" << NdbObject->getNdbError() <<
// " ErrorCode = " << NdbObject->getNdbError() << endl;
ndbout << "executeCallback threadInfo->transactionCompleted = " <<
threadInfo->transactionCompleted << endl;
diff --git a/storage/ndb/test/ndbapi/initronja.cpp b/storage/ndb/test/ndbapi/initronja.cpp
index 9b96e7e8625..2aa7d575710 100644
--- a/storage/ndb/test/ndbapi/initronja.cpp
+++ b/storage/ndb/test/ndbapi/initronja.cpp
@@ -302,13 +302,13 @@ inline int InsertRecords(Ndb* pNdb, int nNoRecords){
return 0;
error_handler1:
- ndbout << "Error occured in getNdbOperation " << endl;
+ ndbout << "Error occurred in getNdbOperation " << endl;
ndbout << MyTransaction->getNdbError() << endl;
pNdb->closeTransaction(MyTransaction);
return -1 ;
error_handler2:
- ndbout << "Error occured in defining operation " << endl;
+ ndbout << "Error occurred in defining operation " << endl;
ndbout << MyOperation[count_tables]->getNdbError() << endl;
pNdb->closeTransaction(MyTransaction);
return -1 ;
@@ -318,13 +318,13 @@ error_handler3:
return -1 ;
error_handler4:
- ndbout << "Error occured in equal " << endl;
+ ndbout << "Error occurred in equal " << endl;
ndbout << MyOperation[count_tables]->getNdbError() << endl;
pNdb->closeTransaction(MyTransaction);
return -1 ;
error_handler5:
- ndbout << "Error occured in get/setValue " << endl;
+ ndbout << "Error occurred in get/setValue " << endl;
ndbout << MyOperation[count_tables]->getNdbError() << endl;
pNdb->closeTransaction(MyTransaction);
return -1 ;
diff --git a/storage/ndb/test/ndbapi/testNdbApi.cpp b/storage/ndb/test/ndbapi/testNdbApi.cpp
index 0d631023f75..c4d313a267b 100644
--- a/storage/ndb/test/ndbapi/testNdbApi.cpp
+++ b/storage/ndb/test/ndbapi/testNdbApi.cpp
@@ -1011,7 +1011,7 @@ int runCheckGetNdbErrorOperation(NDBT_Context* ctx, NDBT_Step* step){
for(int a = 0; a<pTab->getNoOfColumns(); a++){
if (pTab->getColumn(a)->getPrimaryKey() == true){
if(hugoOps.equalForAttr(pOp, a, 1) != 0){
- // An error has occured, check that
+ // An error has occurred, check that
// it's possible to get the NdbErrorOperation
const NdbError err = pCon->getNdbError();
ERR(err);
diff --git a/storage/ndb/test/ndbapi/testTimeout.cpp b/storage/ndb/test/ndbapi/testTimeout.cpp
index 711a943f965..519946d83d7 100644
--- a/storage/ndb/test/ndbapi/testTimeout.cpp
+++ b/storage/ndb/test/ndbapi/testTimeout.cpp
@@ -511,7 +511,7 @@ TESTCASE("TimeoutRandTransaction",
}
TESTCASE("BuddyTransNoTimeout",
"Start a transaction and perform an insert with NoCommit. " \
- "Start a buddy transaction wich performs long running scans " \
+ "Start a buddy transaction which performs long running scans " \
"and sleeps. " \
"The total sleep time is longer than TransactionInactiveTimeout" \
"Commit the first transaction, it should not have timed out."){
@@ -523,7 +523,7 @@ TESTCASE("BuddyTransNoTimeout",
}
TESTCASE("BuddyTransNoTimeout5",
"Start a transaction and perform an insert with NoCommit. " \
- "Start a buddy transaction wich performs long running scans " \
+ "Start a buddy transaction which performs long running scans " \
"and sleeps. " \
"The total sleep time is longer than TransactionInactiveTimeout" \
"Commit the first transaction, it should not have timed out." \
diff --git a/storage/ndb/test/ndbapi/test_event.cpp b/storage/ndb/test/ndbapi/test_event.cpp
index e435c59e457..92856d38602 100644
--- a/storage/ndb/test/ndbapi/test_event.cpp
+++ b/storage/ndb/test/ndbapi/test_event.cpp
@@ -254,7 +254,7 @@ eventOperation(Ndb* pNdb, const NdbDictionary::Table &tab, void* pstats, int rec
last_inconsitant_gci = gci;
stats.n_inconsistent_gcis++;
}
- g_warning << "A node failure has occured and events might be missing\n";
+ g_warning << "A node failure has occurred and events might be missing\n";
}
g_info << function << "GCI " << gci << ": " << count;
struct receivedEvent* recEvent;
@@ -1166,7 +1166,7 @@ static int copy_events(Ndb *ndb)
r++;
if (!pOp->isConsistent()) {
- g_err << "A node failure has occured and events might be missing\n";
+ g_err << "A node failure has occurred and events might be missing\n";
DBUG_RETURN(-1);
}
diff --git a/storage/ndb/test/ndbapi/test_event_multi_table.cpp b/storage/ndb/test/ndbapi/test_event_multi_table.cpp
index a8cf0fa86c0..04e5caa7e9c 100644
--- a/storage/ndb/test/ndbapi/test_event_multi_table.cpp
+++ b/storage/ndb/test/ndbapi/test_event_multi_table.cpp
@@ -95,7 +95,7 @@ static int copy_events(Ndb *ndb)
Uint32 gci= pOp->getGCI();
if (!pOp->isConsistent()) {
- g_err << "A node failure has occured and events might be missing\n";
+ g_err << "A node failure has occurred and events might be missing\n";
DBUG_RETURN(-1);
}
diff --git a/storage/ndb/tools/restore/restore_main.cpp b/storage/ndb/tools/restore/restore_main.cpp
index 9af989e457a..c8e9b3e0f6e 100644
--- a/storage/ndb/tools/restore/restore_main.cpp
+++ b/storage/ndb/tools/restore/restore_main.cpp
@@ -862,7 +862,7 @@ main(int argc, char** argv)
if (res < 0)
{
- err <<" Restore: An error occured while restoring data. Exiting...";
+ err <<" Restore: An error occurred while restoring data. Exiting...";
err << endl;
exitHandler(NDBT_FAILED);
}
@@ -875,7 +875,7 @@ main(int argc, char** argv)
if (res < 0)
{
- err << "Restore: An error occured while restoring data. Exiting... "
+ err << "Restore: An error occurred while restoring data. Exiting... "
<< "res= " << res << endl;
exitHandler(NDBT_FAILED);
}
diff --git a/storage/xtradb/fts/fts0opt.cc b/storage/xtradb/fts/fts0opt.cc
index e096b8bf6d6..0703b050848 100644
--- a/storage/xtradb/fts/fts0opt.cc
+++ b/storage/xtradb/fts/fts0opt.cc
@@ -598,7 +598,7 @@ fts_zip_read_word(
/* Finished decompressing block. */
if (zip->zp->avail_in == 0) {
- /* Free the block thats been decompressed. */
+ /* Free the block that's been decompressed. */
if (zip->pos > 0) {
ulint prev = zip->pos - 1;
diff --git a/storage/xtradb/os/os0file.cc b/storage/xtradb/os/os0file.cc
index 9851ec132e5..7e4e59278fa 100644
--- a/storage/xtradb/os/os0file.cc
+++ b/storage/xtradb/os/os0file.cc
@@ -2931,7 +2931,7 @@ try_again:
"Error in system call pread(). The operating"
" system error number is %lu.",(ulint) errno);
} else {
- /* Partial read occured */
+ /* Partial read occurred */
ib_logf(IB_LOG_LEVEL_ERROR,
"Tried to read " ULINTPF " bytes at offset "
UINT64PF ". Was only able to read %ld.",
@@ -3035,7 +3035,7 @@ try_again:
"Error in system call pread(). The operating"
" system error number is %lu.",(ulint) errno);
} else {
- /* Partial read occured */
+ /* Partial read occurred */
ib_logf(IB_LOG_LEVEL_ERROR,
"Tried to read " ULINTPF " bytes at offset "
UINT64PF ". Was only able to read %ld.",
diff --git a/storage/ndb/src/ndbapi/NdbTransaction.cpp b/storage/ndb/src/ndbapi/NdbTransaction.cpp
index f446267f3b2..7c3e360b9fc 100644
--- a/storage/ndb/src/ndbapi/NdbTransaction.cpp
+++ b/storage/ndb/src/ndbapi/NdbTransaction.cpp
@@ -1747,7 +1747,7 @@ transactions.
}
/**********************************************************************/
/* A serious error has occured. This could be due to deadlock or */
/* lack of resources or simply a programming error in NDB. This */
/* transaction will be aborted. Actually it has already been */
/* and we only need to report completion and return with the */
@@ -1869,7 +1869,7 @@ NdbTransaction::receiveTCKEY_FAILCONF(const TcKeyFailConf * failConf)
*/
if(checkState_TransId(&failConf->transId1)){
/*
- A node failure of the TC node occured. The transaction has
+ A node failure of the TC node occurred. The transaction has
been committed.
*/
theCommitStatus = Committed;
@@ -1747,7 +1747,7 @@ transactions.
}
/**********************************************************************/
- /* A serious error has occured. This could be due to deadlock or */
+ /* A serious error has occurred. This could be due to deadlock or */
/* lack of resources or simply a programming error in NDB. This */
/* transaction will be aborted. Actually it has already been */